function  [nQ, LQ, WQ, A] = runSingleserver4B(seed, tEnd)
% runs model singleserver4B with given seed and end time
% returns
% nQ   actual queue length over time (structure with time)
% WQ   average queue waiting time 
% LQ   average queue length
% A    average server load
model = 'singleserver4B';
set_param([model, '/Generator'], 'seed', num2str(seed))
set_param([model, '/Server'], 'seed', num2str(seed+1))
simOut = sim(model, 'StopTime', num2str(tEnd));
nQ = simOut.nQ;
LQ = simOut.LQ(end);
WQ = simOut.WQ(end);
A = simOut.A(end);
